/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.reporting;

/**
 * <p>
 * Defines utilities to validate variables.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
final class Validator {
    /**
     * <p>
     * Creates a new instance of <code>Validator</code> class. This private constructor prevents the creation of a
     * new instance.
     * </p>
     */
    private Validator() {
    }

    /**
     * <p>
     * Validates the value of a variable with type <code>Object</code>. The value cannot be <code>null</code>.
     * </p>
     *
     * @param value value of the variable.
     * @param name name of the variable.
     *
     * @throws NullPointerException if <code>value</code> is <code>null</code>.
     */
    public static void validateNotNull(Object value, String name) {
        if (value == null) {
            throw new NullPointerException(name + " cannot be null.");
        }
    }

    /**
     * <p>
     * Validates the value of a string variable. The value cannot be empty string, but may be <code>null</code>.
     * </p>
     *
     * @param value value of the variable.
     * @param name name of the variable.
     *
     * @throws IllegalArgumentException if <code>value</code> is empty string.
     */
    public static void validateNotEmpty(String value, String name) {
        if (value != null) {
            if (value.trim().length() == 0) {
                throw new IllegalArgumentException(name + " cannot be empty string.");
            }
        }
    }

    /**
     * <p>
     * Validates the value of a string variable. The value cannot be <code>null</code> and empty string.
     * </p>
     *
     * @param value value of the variable.
     * @param name name of the variable.
     *
     * @throws NullPointerException if <code>value</code> is <code>null</code>.
     * @throws IllegalArgumentException if <code>value</code> is empty string.
     */
    public static void validateNotNullOrEmpty(String value, String name) {
        validateNotNull(value, name);
        validateNotEmpty(value, name);
    }
}



