/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.processor.linecounter;

import java.util.Map;

/**
 * <p>
 * Defines helper methods for line counters.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 2.0b
 */
final class LineCounterHelper {
    /**
     * <p>
     * Creates a new instance of <code>LineCounterHelper</code> class. This private constructor prevents from creating
     * an instance of this class.
     * </p>
     */
    private LineCounterHelper() {
    }

    /**
     * <p>
     * Gets a flag indicating whether the given switch is specified in the arguments. The value of the switch is
     * ignored, but must be a string if exists.
     * </p>
     *
     * @param arguments the argument names and values received from the command line.
     * @param switchName the switch name to be examined.
     *
     * @throws NullPointerException if <code>arguments</code> is <code>null</code>.
     * @throws IllegalArgumentExcpetion if the value of the given switch is not <code>null</code> and
     *         not a string.
     * @return <code>true</code> if the given switch is specified in the arguments; <code>false</code> otherwise.
     */
    public static boolean isSwitchSpecified(Map arguments, String switchName) {
        if (arguments == null) {
            throw new NullPointerException("arguments cannot be null.");
        }

        Object obj = arguments.get(switchName);

        // If the value is not null and not a string, illegal argument exception.
        if ((obj != null) && !(obj instanceof String)) {
            throw new IllegalArgumentException("The value of switches must be string.");
        }

        // If the value is available, the switch is specified.
        return (obj != null);
    }
}
