/**
 * Copyright (c) 2005, TopCoder, Inc. All rights reserved.
 */
package com.topcoder.file.statistics.accuracytests.matcher;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileMatcher;
import com.topcoder.file.statistics.accuracytests.TestHelper;
import com.topcoder.file.statistics.matcher.MimeMatcher;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;


/**
 * <p>
 * Accuracy tests for MimeMatcher.
 * </p>
 *
 * @author cucu
 * @version 1.0
 */
public class MimeMatcherAccuracyTests extends TestCase {

    /**
     * Set up for each test: load magic numbers configuration
     */
    public void setUp() throws Exception {
        TestHelper.unloadNamespace(TestHelper.MAGIC_NUMBERS_NAMESPACE);
        TestHelper.loadConfig(TestHelper.MAGIC_NUMBERS_CONFIG);
    }

    /**
     * Tear down: load magic numbers configurationun
     */
    public void tearDown() throws Exception {
        TestHelper.unloadNamespace(TestHelper.MAGIC_NUMBERS_NAMESPACE);
    }

    /**
     * Test the Match method against a single Mime type.
     */
    public void testMatchWithStringConstructor() throws Exception  {
        FileMatcher matcher = new MimeMatcher("binary/zip");

        assertTrue(TestHelper.ZIP_FILE + " should match against 'binary/zip' mime",
                matcher.match(new File(TestHelper.ZIP_FILE)));

        assertFalse(TestHelper.DLL_FILE + " should NOT match against 'binary/zip' mime",
                matcher.match(new File(TestHelper.DLL_FILE)));

        assertFalse(TestHelper.TXT_FILE + " should NOT match against 'binary/zip' mime",
                matcher.match(new File(TestHelper.TXT_FILE)));

        assertFalse(TestHelper.CS_FILE + " should NOT match against 'binary/zip' mime",
                matcher.match(new File(TestHelper.CS_FILE)));

    }


    /**
     * Test that the list constructor makes a copy of the list
     */
    public void testListConstructor() throws Exception {
        List mimes = new ArrayList();
        mimes.add("binary/zip");

        FileMatcher matcher = new MimeMatcher(mimes);

        // this shouldn't affect the matcher
        mimes.add("application/x-ms-dos-executable");

        assertFalse("constructor is not making a copy", matcher.match(new File(TestHelper.DLL_FILE)));
    }

    /**
     * Test the Match method against many mimes, using the constructor that takes a list of types
     */
    public void testMatchWithListConstructor() throws Exception  {
        List mimes = new ArrayList();
        mimes.add("binary/zip");
        mimes.add("application/x-ms-dos-executable");

        FileMatcher matcher = new MimeMatcher(mimes);

        checkMimes(matcher);
    }

    /**
     *  Test the Match method against many mimes, using the constructor that reads from the configuration file.
     *
     * @throws Exception to JUnit
     */
    public void testMatchWithConfigManagerConstructor() throws Exception  {
        TestHelper.loadConfig(TestHelper.MATCHERS_CONFIG);

        try {
            Property prop = ConfigManager.getInstance().getPropertyObject(TestHelper.MATCHER_NAMESPACE , "mime");
            FileMatcher matcher = new MimeMatcher(prop);
            checkMimes(matcher);
        } finally {
            TestHelper.unloadNamespace(TestHelper.MATCHER_NAMESPACE);
        }
    }

    /**
     * Check that the matcher passed is matching well with the types: ZIP file and Windows executable
     *
     * @param matcher the matcher to check
     */
    private void checkMimes(FileMatcher matcher) throws Exception {
        assertTrue(TestHelper.ZIP_FILE + " should match against mime list",
                matcher.match(new File(TestHelper.ZIP_FILE)));

        assertTrue(TestHelper.DLL_FILE + " should match against mime list",
                matcher.match(new File(TestHelper.DLL_FILE)));

        assertFalse(TestHelper.TXT_FILE + " should NOT match against mime list",
                matcher.match(new File(TestHelper.TXT_FILE)));

        assertFalse(TestHelper.CS_FILE + " should NOT match against mime list",
                matcher.match(new File(TestHelper.CS_FILE)));
    }

}
