/*
 * $(#)BinaryFileMatcherTests.java        Sep 6, 2005
 *
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.matcher;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.file.statistics.matcher.BinaryFileMatcher;

/**
 * This test case contains the failure tests for the <code>BinaryFileMatcher</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class BinaryFileMatcherTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/failuretests/matcher/";

    /**
     * Checks whether the constructor BinaryFileMatcher(Property) properly throws
     * NullPointerException for null argument.
     */
    public void testBinaryFileMatcher() {
        try {
            new BinaryFileMatcher(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Tests the match method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException  if the file is not found
     */
    public void testMatch1() throws IOException {
        try {
            new BinaryFileMatcher().match(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Tests the match method for a file that does not exist. IOException should be thrown.
     */
    public void testMatch2() {
        try {
            new BinaryFileMatcher().match(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException ioe) {
            // success
        }
    }

    /**
     * Tests the isBinary method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException  if the file is not found
     */
    public void testIsBinary1() throws IOException {
        try {
            BinaryFileMatcher.isBinary(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Tests the isBinary method for a file that does not exist. IOException should be thrown.
     */
    public void testIsBinary2() {
        try {
            BinaryFileMatcher.isBinary(new File(BASE_PATH, "inexistent_file"));
            fail("IOException should be thrown");
        } catch (IOException ioe) {
            // success
        }
    }

    /**
     * Tests the isBinary method for a folder. IOException should be thrown.
     */
    public void testIsBinary3() {
        try {
            BinaryFileMatcher.isBinary(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException ioe) {
            // success
        }
    }

}
