/*
 * $(#)TextLineCounterTests.java        Sep 6, 2005
 *
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.processor.linecounter;

import java.io.File;
import java.io.IOException;

import junit.framework.TestCase;

import com.topcoder.file.statistics.ConfigurationException;
import com.topcoder.file.statistics.matcher.ExtensionMatcher;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounter;
import com.topcoder.util.config.ConfigManager;
import com.topcoder.util.config.Property;

/**
 * This test case contains the failure tests for the <code>TextLineCounter</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class TextLineCounterTests extends TestCase {

    /**
     * The namespace for this test.
     */
    private static final String NAMESPACE = "com.topcoder.file.statistics.processor.linecounter.failuretests";

    /**
     * The config file for this test.
     */
    private static final String CONFIG_FILE = "failuretests/processor/config.xml";

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/failuretests/processor/";

    /**
     * An TextLineCounter instance to test.
     */
    private TextLineCounter counter = null;

    /**
     * Load the configuration before testing.
     *
     * @throws Exception to JUnit
     */
    protected void setUp() throws Exception {
        // clear the namespace first
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
        // load the configuration
        ConfigManager.getInstance().add(CONFIG_FILE);

        counter = new TextLineCounter("Text", new ExtensionMatcher("txt"));
    }

    /**
     * Remove the configuration after testing.
     *
     * @throws Exception in case anything goes wrong
     */
    protected void tearDown() throws Exception {
        ConfigManager configManager = ConfigManager.getInstance();
        if (configManager.existsNamespace(NAMESPACE)) {
            configManager.removeNamespace(NAMESPACE);
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
     * NullPointerException for null argument.
     */
    public void testTextLineCounter1() {
        try {
            new TextLineCounter(null, new ExtensionMatcher("txt"));
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
     * NullPointerException for null argument.
     */
    public void testTextLineCounter2() {
        try {
            new TextLineCounter("alias", null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(String, FileMatcher) properly throws
     * IllegalArgumentException for empty String argument.
     */
    public void testTextLineCounter3() {
        try {
            new TextLineCounter(" ", new ExtensionMatcher("txt"));
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter4() throws Exception {
        try {
            new TextLineCounter((Property) null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter5() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid1");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter6() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid2");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter7() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid3");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter8() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid5");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter9() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid6");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter10() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid7");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter11() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid8");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Checks whether the constructor TextLineCounter(Property) properly throws
     * ConfigurationException for invalid property.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testTextLineCounter12() throws Exception {
        Property property = ConfigManager.getInstance().getPropertyObject(NAMESPACE, "invalid9");

        try {
            new TextLineCounter(property);
            fail("ConfigurationException should be thrown");
        } catch (ConfigurationException e) {
            // success
        }
    }

    /**
     * Tests the process method with null argument. NullPointerException should be thrown.
     *
     * @throws IOException in case anything goes wrong
     */
    public void testProcess1() throws IOException {
        try {
            counter.process(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Tests the process method with a folder as argument. IOException should be thrown.
     */
    public void testProcess2() {
        try {
            counter.process(new File(BASE_PATH));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

    /**
     * Tests the process method with invalid argument. IOException should be thrown.
     */
    public void testProcess3() {
        try {
            counter.process(new File(BASE_PATH, "inexistent_file"));
            fail("IOException should be thrown");
        } catch (IOException e) {
            // success
        }
    }

}
