/*
 * $(#)BasicStatsReportingTests.java        Sep 6, 2005
 *
 * Copyright (c) 2005, TopCoder Inc. All rights reserved.
 */

package com.topcoder.file.statistics.failuretests.reporting;

import java.io.File;

import junit.framework.TestCase;

import com.topcoder.file.statistics.FileProcessor;
import com.topcoder.file.statistics.StatsReportingException;
import com.topcoder.file.statistics.StatsResult;
import com.topcoder.file.statistics.matcher.ExtensionMatcher;
import com.topcoder.file.statistics.processor.linecounter.TextLineCounter;
import com.topcoder.file.statistics.reporting.BasicStatsReporting;

/**
 * This test case contains the failure tests for the <code>BasicStatsReporting</code>
 * class.
 *
 * @author MPhk
 * @version 1.0
 */
public class BasicStatsReportingTests extends TestCase {

    /**
     * The the base path of the test files.
     */
    private static final String BASE_PATH = "test_files/failuretests/reporting";

    /**
     * An BasicStatsReporting instance to test.
     */
    private BasicStatsReporting reporting = null;

    /**
     * A StatsResult instance to test.
     */
    private StatsResult result = null;

    /**
     * A FileProcessor instance to test.
     */
    private FileProcessor processor;

    /**
     * Sets up this test.
     */
    protected void setUp() {
        reporting = new BasicStatsReporting();
        result = new StatsResult();
        processor = new TextLineCounter("text", new ExtensionMatcher("txt"));
    }

    /**
     * Checks whether the constructor BasicStatsReporting(Property) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testBasicStatsReporting() throws Exception {
        try {
            new BasicStatsReporting(null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testAggregate1() throws Exception {
        try {
            reporting.aggregate(null, new File("file"), new StatsResult());
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testAggregate2() throws Exception {
        try {
            reporting.aggregate(processor, null, result);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * NullPointerException for null argument.
     *
     * @throws Exception in case anything goes wrong
     */
    public void testAggregate3() throws Exception {
        try {
            reporting.aggregate(processor, new File("file"), null);
            fail("NullPointerException should be thrown");
        } catch (NullPointerException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * StatsReportingException for invalid file argument.
     */
    public void testAggregate4() {
        reporting.reset(new File(BASE_PATH));

        try {
            reporting.aggregate(processor, new File(BASE_PATH), result);
            fail("StatsReportingException should be thrown");
        } catch (StatsReportingException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * StatsReportingException for invalid file argument.
     */
    public void testAggregate5() {
        reporting.reset(new File(BASE_PATH));

        try {
            reporting.aggregate(processor, new File(BASE_PATH + "invalid_file"), result);
            fail("StatsReportingException should be thrown");
        } catch (StatsReportingException e) {
            // success
        }
    }

    /**
     * Checks whether the method aggregate(FileProcessor, File, StatsResult) properly throws
     * StatsReportingException for invalid file argument.
     */
    public void testAggregate6() {
        reporting.reset(new File(BASE_PATH));

        try {
            reporting.aggregate(processor, new File(new File(BASE_PATH).getParentFile(), "file.txt"), result);
            fail("StatsReportingException should be thrown");
        } catch (StatsReportingException e) {
            // success
        }
    }

    /**
     * Checks whether the method reset(File) properly throws
     * IllegalArgumentException for invalid folder argument.
     */
    public void testReset() {
        try {
            File base = new File("INVALID_DIR");
            reporting.reset(base);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // success
        }
    }

}
