/*
 * Copyright (C) 2005 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.file.statistics.matcher;

import com.topcoder.file.statistics.FileMatcher;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import java.io.File;


/**
 * <p>
 * Tests functionality and error cases of <code>AnyFileMatcher</code> class. The constructors are trivil, so the
 * accuracy tests are omitted.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0b
 * @since 1.0
 */
public class AnyFileMatcherTestCase extends TestCase {
    /** Represents the <code>AnyFileMatcher</code> instance used in tests. */
    private FileMatcher matcher;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     */
    protected void setUp() {
        matcher = new AnyFileMatcher();
    }

    /**
     * <p>
     * Cleans up the test environment. The test instance is disposed.
     * </p>
     */
    protected void tearDown() {
        matcher = null;
    }

    /**
     * <p>
     * Tests constructor <code>AnyFileMatcher(Property)</code> when the given property is <code>null</code>. Expect
     * NullPointerException.
     * </p>
     */
    public void testAnyFileMatcherPropertyNull() {
        try {
            new AnyFileMatcher(null);
            fail("The property is null, should throw NullPointerException.");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests <code>match</code> when the given file is <code>null</code>. Expect NullPointerException.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchNull() throws Exception {
        try {
            matcher.match(null);
            fail("The file is null, should throw NullPointerException.");
        } catch (NullPointerException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests accuracy of <code>match</code>. The matcher matches any file, even non-existing file.
     * </p>
     *
     * @throws Exception pass any unexpected exception to JUnit.
     */
    public void testMatchAccuracy() throws Exception {
        assertTrue("The matcher matches any file.", matcher.match(new File("notexist")));
    }

    /**
     * <p>
     * Aggragates all tests in this class.
     * </p>
     *
     * @return test suite aggragating all tests.
     */
    public static Test suite() {
        return new TestSuite(AnyFileMatcherTestCase.class);
    }
}




